@@ -6,7 +6,7 @@ default_logging_dict = \
         "version": 1,
         "formatters": {
             "default": {
-                "format": "{app_name} %(levelname)9s %(asctime)3s Module: %(module)s - Line: %(lineno)s %(message)s"
+                "format": "%(name)s %(levelname)9s %(asctime)3s Module: %(module)s - Line: %(lineno)s %(message)s"
             }
         },
         "handlers": {
@@ -38,16 +38,15 @@ default_logging_dict = \
 class Client:
 
     def __init__(self, app_name):
-        self.app_name = app_name
-        self._logger = self._load_logger()
+        self._logger = self._load_logger(app_name)
 
     @property
     def logger(self):
         return self._logger
 
     @staticmethod
-    def _load_logger():
+    def _load_logger(app_name):
 
         logging.config.dictConfig(default_logging_dict)
-        return logging.getLogger('default')
+        return logging.getLogger(app_name)
 
